###############
PyDMScatterPlot
###############

.. autoclass:: pydm.widgets.scatterplot.PyDMScatterPlot
   :members:
   :show-inheritance:

#####################
ScatterPlotCurveItem
#####################

.. autoclass:: pydm.widgets.scatterplot.ScatterPlotCurveItem
   :members:
   :show-inheritance:
